function [H_alpha] = HRenyi_kNN_S_estimation(Y,co)
%Estimates the Rnyi entropy (H_alpha) of Y (Y(:,t) is the t^th sample) using the generalized k-nearest neighbor (S\subseteq {1,...,k}) method. Cost parameters are provided in the cost object co.
%
%We make use of the naming convention 'H<name>_estimation', to ease embedding new entropy estimation methods.
%
%REFERENCE: 
%   Dvid Pl, Barnabs Pczos, Csaba Szepesvri: Estimation of Rnyi Entropy and Mutual Information Based on Generalized Nearest-Neighbor Graphs. NIPS-2010, pages 1849-1857.
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

[d,num_of_samples] = size(Y);
squared_distances = kNN_squared_distances(Y,Y,co,1);
p = d * (1-co.alpha);

%co.mult:OK.

%H_alpha estimation up to an additive constant:
    L = sum(sum(squared_distances(co.k,:).^(p/2),1)); %'p/2' <= squared; S=co.k
    H_alpha = log( L / num_of_samples^co.alpha) / (1-co.alpha); 
