function [co] = Hensemble_initialization(mult)
%Initialization of the "meta" entropy estimator. The
%estimator is:
%   1)constructed from the average of entropy estimations on groups of samples.
%   2)treated as a cost object (co). 
%
%Here, we make use of the naming convention: 'H<name>_initialization', to ease embedding new entropy estimation methods.
%
%INPUT:
%   mult: is a multiplicative constant relevant (needed) in the estimation; '=1' means yes, '=0' no.
%OUTPUT:
%   co: object (structure).
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

%mandatory fields:
    co.name = 'ensemble';
    co.mul = mult;
    
%other fields:
    co.group_size = 500;%assumption: co.group_size <= number of samples
    co.member_name = 'Shannon_kNN_k'; %you can change it to any Shannon entropy estimator.
    co.member_co = H_initialization(co.member_name,mult);
