function [I] = IL2_DL2_estimation(Y,ds,co)
%Estimates mutual information (I) making use of an(y) estimator for L2 divergence; co is the cost object.
%This is a  "meta" method, using the relation: I(y^1,...,y^M) = D(f_y,\prod_{m=1}^M f_{y^m}).
%
%We make use of the naming convention 'I<name>_estimation', to ease embedding new mutual information estimation methods.
%
%INPUT:
%   Y:Y(:,t) t^th sample.
%  ds: subspace dimensions.
%  co: mutual information estimator object.
%REFERENCE:
%   Barnabs Pczos, Zoltn Szab, Jeff Schneider: Nonparametric divergence estimators for Independent Subspace Analysis. EUSIPCO-2011, pages 1849-1853.
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

[Y1,Y2] = div_sample_generation(Y,ds);
I = D_estimation(Y1,Y2,co.member_co);